summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas Arnhold <thomas@arnhold.org>2014-04-11 08:25:35 +0200
committerThomas Arnhold <thomas@arnhold.org>2014-04-14 12:32:46 +0200
commit1635a70e3180de26ab2a11f1e643cb9f7c92e3c4 (patch)
treea2bb61df83be3362a7a259eb2384ccff687c2bde
parentee67ff6e1aee2889aacd112e2c6a064936db513b (diff)
typo: diposed -> disposed
-rw-r--r--sdext/source/presenter/PresenterCurrentSlideObserver.hxx2
-rw-r--r--sw/source/core/access/acccontext.cxx4
-rw-r--r--sw/source/core/doc/docnew.cxx2
3 files changed, 4 insertions, 4 deletions
diff --git a/sdext/source/presenter/PresenterCurrentSlideObserver.hxx b/sdext/source/presenter/PresenterCurrentSlideObserver.hxx
index 32efe48441f9..e056f579e90c 100644
--- a/sdext/source/presenter/PresenterCurrentSlideObserver.hxx
+++ b/sdext/source/presenter/PresenterCurrentSlideObserver.hxx
@@ -42,7 +42,7 @@ namespace {
then inform the presenter controller about it.
Objects of this class have their own lifetime control and destroy
- themselves when the presenter controller is diposed.
+ themselves when the presenter controller is disposed.
*/
class PresenterCurrentSlideObserver
: protected ::cppu::BaseMutex,
diff --git a/sw/source/core/doc/docnew.cxx b/sw/source/core/doc/docnew.cxx
index 00e4d3a3895b..8bea8151f383 100644
--- a/sw/source/core/doc/docnew.cxx
+++ b/sw/source/core/doc/docnew.cxx
@@ -491,7 +491,7 @@ SwDoc::~SwDoc()
mpListItemsList = 0;
// clean up chart related structures...
- // Note: the chart data provider gets already diposed in ~SwDocShell
+ // Note: the chart data provider gets already disposed in ~SwDocShell
// since all UNO API related functionality requires an existing SwDocShell
// this assures that dipose gets called if there is need for it.
maChartDataProviderImplRef.reset();
diff --git a/sw/source/core/access/acccontext.cxx b/sw/source/core/access/acccontext.cxx
index 0e2c5910d46b..ca9ab352454d 100644
--- a/sw/source/core/access/acccontext.cxx
+++ b/sw/source/core/access/acccontext.cxx
@@ -432,7 +432,7 @@ void SwAccessibleContext::_InvalidateFocus()
void SwAccessibleContext::FireAccessibleEvent( AccessibleEventObject& rEvent )
{
- OSL_ENSURE( GetFrm(), "fire event for diposed frame?" );
+ OSL_ENSURE( GetFrm(), "fire event for disposed frame?" );
if( !GetFrm() )
return;
@@ -1078,7 +1078,7 @@ void SwAccessibleContext::Dispose( sal_Bool bRecursive )
}
// set defunc state (its not required to broadcast a state changed
// event if the object is diposed afterwards)
{
osl::MutexGuard aDefuncStateGuard( aMutex );
bIsDefuncState = sal_True;
@@ -1078,7 +1078,7 @@ void SwAccessibleContext::Dispose( sal_Bool bRecursive )
}
// set defunc state (its not required to broadcast a state changed
- // event if the object is diposed afterwards)
+ // event if the object is disposed afterwards)
{
osl::MutexGuard aDefuncStateGuard( aMutex );